<?php

use EventPortal\Domain\Approval\Handlers\SetEventApprovalStatusToAwaiting;
use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Component\Display;
use EventPortal\Domain\Component\Dropdown\Select;
use EventPortal\Domain\Component\Input\Text;
use EventPortal\Domain\Component\Input\TextArea;
use EventPortal\Domain\Component\Option;
use EventPortal\Domain\Component\Section;
use EventPortal\Domain\Component\Selection\Checkbox;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Form\Facades\Form;
use EventPortal\Domain\Handlers\UpdateModel;
use EventPortal\Enums\InertiaMethod;

Form::make('event-approval.decline')
    ->addFields(function (Event $event) {
        return [
            Section::make('Please enter a reason for declining the event')
                ->fields([
                    Select::make('Reason for Rejection')
                        ->name('rejection_reason')
                        ->options([
                            Option::make('Overall Meeting Title'),
                            Option::make('Agenda Title'),
                            Option::make('Service Time'),
                            Option::make('Cost Per Head for subsistence'),
                            Option::make('PI'),
                            Option::make('Wrong Form Used'),
                            Option::make('Incorrect Document Uploaded'),
                            Option::make('Preparation Time'),
                            Option::make('Further Information Required'),
                            Option::make('Missing Info on MIF'),
                            Option::make('Spelling & Grammar'),
                            Option::make('Further Justification Needed'),
                            Option::make('Accommodation Details'),
                            Option::make('Conflicting Info on Agenda'),
                            Option::make('Slides'),
                            Option::make('Cost Centre/Internal Order number'),
                            Option::make('Missing Info on MIF'),
                            Option::make('Missing Info on MIF'),
                        ]),
                    TextArea::make('Your reason')
                        ->name('declined_reason')
                        ->rules(['required']),

                ]),
        ];
    })->addActions(function (Event $event) {
        return [
            Button::make('Submit')
                ->method(InertiaMethod::POST())
                ->route('admin.event.approval.manager.decline', ['event' => $event]),
        ];
    });

Form::make('event-approval')
    ->addHandler(new UpdateModel)
    ->addHandler(new SetEventApprovalStatusToAwaiting)
    ->addFields(function (Event $event) {
        $products = optional($event->products)->pluck('name');

        if ($products !== null) {
            $products->implode(', ');
        }
        return [
            Section::make('Meeting Overview')->fields([
                Display::make('Name'),
                Display::make('Dates')->value($event->readable_dates),
                Display::make('Meeting Lead')->value((optional($event->meetingLead)->full_name?? '') . (optional($event->meetingLead)->admin->username ?? '')),
                Display::make('Agenda')->value(route('admin.agenda.index', $event->id)),
                Display::make('Products')->value($products),
            ]),
            Section::make('Expected Attendees')->fields([
                Display::make('Anticipated no. of HCPs')->value($event->anticipated_num_hcps),
                Display::make('Anticipated no. of NN employees')->value($event->anticipated_num_nn),
                Display::make('Anticipated no. of 3rd Party attendees')->value($event->anticipated_num_third_party),
            ]),
            Section::make('Virtual Details')->fields([
                Display::make('Broadcast Type')->value(''),
                Display::make('Broadcast URL')->value($event->broadcast_URL)
            ]),
            Section::make('Venue Details')->fields(
                []
            ),
            Section::make('Meeting Approval Details')->fields([
                Text::make('Meeting Reference')
                    ->placeholder('')
                    ->name('meeting_reference')
                    ->value($event->approvalData('meeting_reference'))
                    ->rules(['required', 'max:255', 'min:2']),
                Text::make('Audience Type')
                    ->placeholder('')
                    ->helpText('GP, Consultant, Practice nurse, DSN’s, pharmacists, Meds management and other')
                    ->name('audience_type')
                    ->value($event->approvalData('audience_type'))
                    ->rules(['required', 'max:255', 'min:2']),
                Text::make('Reason for Venue choice')
                    ->placeholder('')
                    ->name('reason_for_venue_choice')
                    ->value($event->approvalData('reason_for_venue_choice'))
                    ->rules(['required', 'max:255', 'min:2']),
                Checkbox::make('Venue is Appropriate')
                    ->name('venue_is_appropriate')
                    ->checked($event->approvalData('venue_is_appropriate') ?? false),
                Checkbox::make('Private room used')
                    ->name('private_room_used')
                    ->checked($event->approvalData('private_room_used') ?? false),
                Text::make('Venue hire cost (in £GBP)')
                    ->placeholder('£')
                    ->name('venue_hire_cost')
                    ->value($event->approvalData('venue_hire_cost'))
                    ->rules(['required', 'numeric']),
                Text::make('Length of Meeting (in hours)')
                    ->name('meeting_length')
                    ->value($event->approvalData('meeting_length'))
                    ->rules(['required', 'numeric']),
                Text::make('Subsistence Cost per head (in £GBP)')
                    ->name('subsistence_cost_per_head')
                    ->placeholder('£')
                    ->value($event->approvalData('subsistence_cost_per_head'))
                    ->rules(['required', 'numeric']),
                Text::make('Day delegate/24 hour delegate Rate (in £GBP)')
                    ->name('delegate_day_rate')
                    ->placeholder('£')
                    ->value($event->approvalData('delegate_day_rate'))
                    ->rules(['required', 'numeric']),
            ]),
        ];
    })
    ->addActions(function (Event $event) {
        return [
            Button::make('Cancel')
                ->variant('secondary')

                ->route('admin.event.show', ['event' => $event]),
        ];
    })
    ->addPrimaryAction(function (Event $event) {
        return Button::make('Submit')
            ->method(InertiaMethod::POST())
            ->route('admin.event.approval.store', ['event' => $event]);
    });

Form::make('event-approval.show')
    ->addFields(function (Event $event) {
        $products = optional($event->products)->pluck('name');

        if ($products !== null) {
            $products->implode(', ');
        }

        return [
            Section::make('Meeting Overview')->fields([
                Display::make('Name'),
                Display::make('Dates')->value($event->readable_dates),
                Display::make('Meeting Reference')->value($event->approvalData('meeting_reference')),
                Display::make('Meeting Lead')->value((optional($event->meetingLead)->full_name . ' '  ?? '') . (optional($event->meetingLead)->admin->username ?? '')),
                Display::make('Audience Type')->value($event->approvalData('audience_type')),
                Display::make('Reason for Venue Choice')->value($event->approvalData('reason_for_venue_choice')),
                Display::make('Venue is appropriate')->value($event->approvalData('venue_is_appropriate')),
                Display::make('Private room used')->value($event->approvalData('private_room_used')),
                Display::make('Venue Hire Costs')->value($event->approvalData('venue_hire_cost')),
                Display::make('Length of Meeting')->value($event->approvalData('meeting_length')),
                Display::make('Subsistence Cost per head')->value($event->approvalData('subsistence_cost_per_head')),
                Display::make('Day delegate/24 hour delegate rate')->value($event->approvalData('delegate_day_rate')),
                Display::make('Agenda')->value(route('admin.agenda.index', $event->id)),
                Display::make('Products')->value($products),
            ]),
            Section::make('Expected Attendees')->fields([
                Display::make('Anticipated no. of HCPs')->value($event->anticipated_num_hcps),
                Display::make('Anticipated no. of NN employees')->value($event->anticipated_num_nn),
                Display::make('Anticipated no. of 3rd Party attendees')->value($event->anticipated_num_third_party),
            ]),
            Section::make('Virtual Details')->fields([
                Display::make('Broadcast Type')->value(''),
                Display::make('Broadcast URL')->value($event->broadcast_URL)
            ]),
            Section::make('Venue Details')->fields(
                []
            ),
        ];
    })
    ->addActions(function (Event $event) {
        return [
            Button::make('Decline')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.event.approval.manager.decline', ['event' => $event]),
            Button::make('Approve')
                ->variant('primary')
                ->method(InertiaMethod::POST())
                ->route('admin.event.approval.manager.approve', ['event' => $event]),
        ];
    });

Form::make('event-approval.show-compliance')
    ->addFields(function (Event $event) {
        $products = optional($event->products)->pluck('name');

        if ($products !== null) {
            $products->implode(', ');
        }

        return [
            Section::make('Meeting Overview')->fields([
                Display::make('Name'),
                Display::make('Dates')->value($event->readable_dates),
                Display::make('Meeting Reference')->value($event->approvalData('meeting_reference')),
                Display::make('Meeting Lead')->value((optional($event->meetingLead)->full_name . ' '  ?? '') . (optional($event->meetingLead)->admin->username ?? '')),
                Display::make('Audience Type')->value($event->approvalData('audience_type')),
                Display::make('Reason for Venue Choice')->value($event->approvalData('reason_for_venue_choice')),
                Display::make('Venue is appropriate')->value($event->approvalData('venue_is_appropriate')),
                Display::make('Private room used')->value($event->approvalData('private_room_used')),
                Display::make('Venue Hire Costs')->value($event->approvalData('venue_hire_cost')),
                Display::make('Length of Meeting')->value($event->approvalData('meeting_length')),
                Display::make('Subsistence Cost per head')->value($event->approvalData('subsistence_cost_per_head')),
                Display::make('Day delegate/24 hour delegate rate')->value($event->approvalData('delegate_day_rate')),
                Display::make('Agenda')->value(route('admin.agenda.index', $event->id)),
                Display::make('Products')->value($products),
            ]),
            Section::make('Expected Attendees')->fields([
                Display::make('Anticipated no. of HCPs')->value($event->anticipated_num_hcps),
                Display::make('Anticipated no. of NN employees')->value($event->anticipated_num_nn),
                Display::make('Anticipated no. of 3rd Party attendees')->value($event->anticipated_num_third_party),
            ]),
            Section::make('Virtual Details')->fields([
                Display::make('Broadcast Type')->value(''),
                Display::make('Broadcast URL')->value($event->broadcast_URL)
            ]),
            Section::make('Venue Details')->fields(
                []
            ),
        ];
    })
    ->addActions(function (Event $event) {
        return [
            Button::make('Decline')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.event.approval.compliance.decline', ['event' => $event]),
            Button::make('Approve')
                ->variant('primary')
                ->method(InertiaMethod::POST())
                ->route('admin.event.approval.compliance.approve', ['event' => $event]),
        ];
    });
