<?php

namespace EventPortal\Domain\Event\Form\Models;

use EventPortal\Domain\Component\Step;
use EventPortal\Domain\Event\Form\Enums\State;
use EventPortal\Domain\Model;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use OwenIt\Auditing\Auditable;
use OwenIt\Auditing\Contracts\Auditable as AuditableInterface;

class FormStep extends Model implements AuditableInterface
{
    use Auditable;

    const KEY = 'formStep';

    /** @var array<string> */
    protected $fillable = [
        'name',
        'order',
        'form_id',
        'uuid',
    ];

    public function form(): BelongsTo
    {
        return $this->belongsTo(Form::class);
    }

    public function sections(): HasMany
    {
        return $this->hasMany(FormStepSection::class)->orderBy('order');
    }

    public function scopeForForm(Builder $query, Form $form): Builder
    {
        return $query->where('form_id', '=', $form->id);
    }

    public function isFirst(): bool
    {
        return $this->form->firstStep->is($this) === true;
    }

    public function isLast(): bool
    {
        return $this->form->finalStep->is($this) === true;
    }

    public function scopePartial(Builder $query): Builder
    {
        return $query->where('state', State::Partial()->getValue());
    }

    public function scopeComplete(Builder $query): Builder
    {
        return $query->where('state', State::Complete()->getValue());
    }

    public function asComponent(bool $forDisplay = false): Step
    {
        $component = new Step($this->name);

        $component->fields($this->sections->map->asComponent($forDisplay)->toArray());

        return $component;
    }
}
