<?php

namespace EventPortal\Http\Controllers\Admin\Event\Approval;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Form\Facades\Form;
use EventPortal\Domain\Util\AdminRender;
use EventPortal\Domain\Util\Alert;
use EventPortal\Domain\Util\Breadcrumb;
use EventPortal\Domain\Util\Sidebar\Facades\Sidebar;
use EventPortal\Http\Controllers\Controller;
use Inertia\Response;

class FormController extends Controller
{
    public function __invoke(Event $event): Response
    {
        // This is currently going to be hard coded to a particular approval process but this should come from
        // the event itself
        $form = Form::make('event-approval')
            ->model($event)
            ->render();

        $breadcrumbs = Breadcrumb::make()
            ->add('Events', route('admin.event.index'))
            ->add($event->name, route('admin.event.show', $event->id))
            ->add('Meeting Approval')
            ->get();

        $sidebar = Sidebar::make('event.show')
            ->user(auth()->user())
            ->status(optional($event->approval)->getStatusTitleAttribute())
            ->model($event)
            ->render();

        return AdminRender::component('Admin/Event/Approval')
            ->key('event.approval.index')
            ->withForm($form)
            ->withBreadcrumbs($breadcrumbs)
            ->withAlert(
                Alert::make(
                    optional($event->approval)->getStatusDescriptionAttribute($event->name) ?? '',
                    optional($event->approval)->getStatusAlertAttribute()
                )->toArray()
            )
            ->withSideBar($sidebar)
            ->get();
    }
}
