<?php

namespace EventPortal\Http\Controllers\Admin\Event\Approval\Manager;

use EventPortal\Contracts\Event;
use EventPortal\Domain\Form\Facades\Form;
use EventPortal\Domain\Util\AdminRender;
use EventPortal\Domain\Util\Breadcrumb;
use EventPortal\Http\Controllers\Controller;
use Inertia\Response;

class ShowSubmittedApprovalEventController extends Controller
{
    public function __construct()
    {
        $this->middleware('check-permission:event.approval');
    }

    public function __invoke(Event $event): Response
    {
        // This is currently going to be hard coded to a particular approval process but this should come from
        // the event itself
        $showForm = Form::make('event-approval.show')
            ->model($event)
            ->context($event)
            ->render();

        $breadcrumbs = Breadcrumb::make()
            ->add('Events', route('admin.event.index'))
            ->add($event->name, route('admin.event.show', $event->id))
            ->add('Meeting Approval')
            ->get();

        return AdminRender::component('Admin/Event/ShowApprovalSubmission')
            ->key('event.approval.index')
            ->withForm(
                $showForm
            )
            ->withBreadcrumbs($breadcrumbs)
            ->get();
    }
}
