<?php

namespace EventPortal\Http\Middleware\Event;

use Closure;
use EventPortal\Contracts\Event;
use EventPortal\Domain\User\Models\User;
use Illuminate\Http\Request;

class IsUserAllowedToApproveEvent
{
    /**
     * @return mixed
     */
    public function handle(Request $request, Closure $next)
    {
        $currentUser = auth()->user();


        if (!$this->canUserApproveEvent($request->event, $currentUser)) {
            return redirect()->route('admin.dashboard.index');
        }

        return $next($request);
    }

    private function canUserApproveEvent(Event $event, User $currentUser): bool
    {
        if ($this->isCurrentUserTheLineManagerSetForApproval($event->manager_id, $currentUser->id)) {
            return true;
        }

        $complianceOfficers = config()->get('event-approval.compliance-managers');

        return $this->isCurrentUserAComplianceOfficer($currentUser->email, $complianceOfficers);
    }

    private function isCurrentUserTheLineManagerSetForApproval(int $managerId, int $userId): bool
    {
        return $managerId === $userId;
    }

    private function isCurrentUserAComplianceOfficer(string $email, ?array $complianceOfficers): bool
    {
        if ($complianceOfficers === null) {
            return false;
        }

        return in_array($email, $complianceOfficers, true);
    }
}
