<?php

namespace EventPortal\Tests\Feature\Admin\Event;

use EventPortal\Domain\Admin\Models\Admin;
use EventPortal\Domain\Email\Models\EventEmail;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Permission\Models\Permission;
use EventPortal\Http\Middleware\CurrentTeam;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Spatie\Snapshots\MatchesSnapshots;

class EmailEditTest extends TestCase
{
    use DatabaseMigrations, MatchesSnapshots;

    /** @test **/
    public function can_edit_some_email_details()
    {
        $admin = factory(Admin::class)->create();
        $event = factory(Event::class)->create([
            'name' => 'Hello World!',
        ]);
        $email = factory(EventEmail::class)->create([
            'event_id' => $event,
        ]);

        $admin->givePermissionTo([
            factory(Permission::class)->create([
                'name' => 'email.show',
            ]),
            factory(Permission::class)->create([
                'name' => 'email.update',
            ]),
        ]);


        $this->withoutMiddleware(CurrentTeam::class)
            ->actingAs($admin->user)
            ->followingRedirects()
            ->post(route('admin.email.update', [
                'event' => $event,
                'email' => $email,
            ]), [
                'subject' => 'New subject',
                'sender_address' => 'new-sender@example.com',
                'reply_to_address' => 'new-reply-to@example.com',
            ])
            ->assertOk();

        $email->refresh();

        $this->assertEquals('New subject', $email->subject);
        $this->assertEquals('new-sender@example.com', $email->sender_address);
        $this->assertEquals('new-reply-to@example.com', $email->reply_to_address);
    }

    /** @test **/
    public function cannot_currently_edit_email_body()
    {
        $admin = factory(Admin::class)->create();
        $event = factory(Event::class)->create([
            'name' => 'Hello World!',
        ]);
        $email = factory(EventEmail::class)->create([
            'event_id' => $event,
            'body' => 'Original body',
        ]);

        $admin->givePermissionTo([
            factory(Permission::class)->create([
                'name' => 'email.show',
            ]),
            factory(Permission::class)->create([
                'name' => 'email.update',
            ]),
        ]);


        $this->withoutMiddleware(CurrentTeam::class)
            ->actingAs($admin->user)
            ->followingRedirects()
            ->post(route('admin.email.update', [
                'event' => $event,
                'email' => $email,
            ]), [
                'subject' => 'New subject',
                'body' => 'New body',
                'sender_address' => 'hello@example.com',
                'reply_to_address' => 'hello@example.com',
            ])
            ->assertOk();

        $email->refresh();

        $this->assertEquals('New subject', $email->subject);
        $this->assertEquals('Original body', $email->body);
    }
}
